/* File: utf8stringbuf_test.h; Copyright and License: see below */

#ifndef UTF8STRINGBUF_TEST_H_
#define UTF8STRINGBUF_TEST_H_

#include "test_suite.h"

test_suite_t utf8stringbuf_test_get_list(void);

#endif /*UTF8STRINGBUF_TEST_H_*/


/*
 * Copyright 2012-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
